@@ -2,11 +2,11 @@
 #
 #
 # TheVirtualBrain-Framework Package. This package holds all Data Management, and 
-# Web-UI helpful to run brain-simulations. To use it, you also need do download
+# Web-UI helpful to run brain-simulations. To use it, you also need to download
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2023, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -19,12 +19,8 @@
 #
 #
 #   CITATION:
-# When using The Virtual Brain for scientific publications, please cite it as follows:
-#
-#   Paula Sanz Leon, Stuart A. Knock, M. Marmaduke Woodman, Lia Domide,
-#   Jochen Mersmann, Anthony R. McIntosh, Viktor Jirsa (2013)
-#       The Virtual Brain: a simulator of primate brain network dynamics.
-#   Frontiers in Neuroinformatics (7:10. doi: 10.3389/fninf.2013.00010)
+# When using The Virtual Brain for scientific publications, please cite it as explained here:
+# https://www.thevirtualbrain.org/tvb/zwei/neuroscience-publications
 #
 #
 
@@ -143,7 +139,7 @@ class ConnectivityCreator(ABCAdapter):
             new_rm.surface = surface
             new_rm.array_data = original_rm.array_data
 
-            result_rm_index = h5.store_complete(new_rm, self.storage_path)
+            result_rm_index = self.store_complete(new_rm)
             result.append(result_rm_index)
 
         return result
@@ -159,15 +155,15 @@ class ConnectivityCreator(ABCAdapter):
         if not view_model.is_branch:
             new_conn_ht = self._cut_connectivity(original_conn_ht, view_model.new_weights,
                                                  view_model.interest_area_indexes, view_model.new_tracts)
-            return [h5.store_complete(new_conn_ht, self.storage_path)]
+            return [self.store_complete(new_conn_ht)]
 
         else:
             result = []
             new_conn_ht = self._branch_connectivity(original_conn_ht, view_model.new_weights,
                                                     view_model.interest_area_indexes, view_model.new_tracts)
-            new_conn_index = h5.store_complete(new_conn_ht, self.storage_path)
+            new_conn_index = self.store_complete(new_conn_ht)
             result.append(new_conn_index)
-            result.extend(self._store_related_region_mappings(view_model.original_connectivity.gid, new_conn_ht))
+            result.extend(self._store_related_region_mappings(view_model.original_connectivity.hex, new_conn_ht))
             return result
 
     @staticmethod
