@@ -2,11 +2,11 @@
 #
 #
 # TheVirtualBrain-Framework Package. This package holds all Data Management, and
-# Web-UI helpful to run brain-simulations. To use it, you also need do download
+# Web-UI helpful to run brain-simulations. To use it, you also need to download
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2023, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -19,12 +19,8 @@
 #
 #
 #   CITATION:
-# When using The Virtual Brain for scientific publications, please cite it as follows:
-#
-#   Paula Sanz Leon, Stuart A. Knock, M. Marmaduke Woodman, Lia Domide,
-#   Jochen Mersmann, Anthony R. McIntosh, Viktor Jirsa (2013)
-#       The Virtual Brain: a simulator of primate brain network dynamics.
-#   Frontiers in Neuroinformatics (7:10. doi: 10.3389/fninf.2013.00010)
+# When using The Virtual Brain for scientific publications, please cite it as explained here:
+# https://www.thevirtualbrain.org/tvb/zwei/neuroscience-publications
 #
 #
 
@@ -68,12 +64,11 @@ class ICAModel(ViewModel):
 
 class ICAForm(ABCAdapterForm):
 
-    def __init__(self, prefix='', project_id=None):
-        super(ICAForm, self).__init__(prefix, project_id)
-        self.datatype = TraitDataTypeSelectField(ICAModel.datatype, self, name='datatype',
-                                                 conditions=self.get_filters())
-        self.i_svar = IntField(ICAModel.i_svar, self, name='i_svar')
-        self.i_mode = IntField(ICAModel.i_mode, self, name='i_mode')
+    def __init__(self):
+        super(ICAForm, self).__init__()
+        self.datatype = TraitDataTypeSelectField(ICAModel.datatype, name='datatype', conditions=self.get_filters())
+        self.i_svar = IntField(ICAModel.i_svar, name='i_svar')
+        self.i_mode = IntField(ICAModel.i_mode, name='i_mode')
 
     @staticmethod
     def get_view_model():
