@@ -2,11 +2,11 @@
 #
 #
 # TheVirtualBrain-Framework Package. This package holds all Data Management, and 
-# Web-UI helpful to run brain-simulations. To use it, you also need do download
+# Web-UI helpful to run brain-simulations. To use it, you also need to download
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2023, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -19,12 +19,8 @@
 #
 #
 #   CITATION:
-# When using The Virtual Brain for scientific publications, please cite it as follows:
-#
-#   Paula Sanz Leon, Stuart A. Knock, M. Marmaduke Woodman, Lia Domide,
-#   Jochen Mersmann, Anthony R. McIntosh, Viktor Jirsa (2013)
-#       The Virtual Brain: a simulator of primate brain network dynamics.
-#   Frontiers in Neuroinformatics (7:10. doi: 10.3389/fninf.2013.00010)
+# When using The Virtual Brain for scientific publications, please cite it as explained here:
+# https://www.thevirtualbrain.org/tvb/zwei/neuroscience-publications
 #
 #
 
@@ -45,7 +41,7 @@ from tvb.core.neocom import h5
 from tvb.core.neotraits.forms import TraitDataTypeSelectField
 from tvb.core.neotraits.view_model import ViewModel, DataTypeGidAttr
 from tvb.datatypes.sensors import SensorsInternal, SensorsEEG, SensorsMEG, Sensors
-from tvb.datatypes.surfaces import Surface, CORTICAL, EEG_CAP
+from tvb.datatypes.surfaces import Surface, SurfaceTypesEnum
 
 LOG = get_logger(__name__)
 
@@ -205,7 +201,8 @@ class SensorsViewer(ABCDisplayer):
 
         params = prepare_sensors_as_measure_points_params(internal_sensors)
 
-        shell_surface = ensure_shell_surface(self.current_project_id, shell_surface, CORTICAL)
+        shell_surface = ensure_shell_surface(self.current_project_id, shell_surface,
+                                             SurfaceTypesEnum.CORTICAL_SURFACE.value)
 
         params['shellObject'] = self.prepare_shell_surface_params(shell_surface, SurfaceURLGenerator)
 
@@ -215,7 +212,7 @@ class SensorsViewer(ABCDisplayer):
     def _params_eeg_sensors(self, eeg_sensors, eeg_cap=None, shell_surface=None):
 
         if eeg_cap is None:
-            eeg_cap = ensure_shell_surface(self.current_project_id, eeg_cap, EEG_CAP)
+            eeg_cap = ensure_shell_surface(self.current_project_id, eeg_cap, SurfaceTypesEnum.EEG_CAP_SURFACE.value)
 
         params = prepare_mapped_sensors_as_measure_points_params(eeg_sensors, eeg_cap, self.stored_adapter.id)
 
