@@ -2,11 +2,11 @@
 #
 #
 # TheVirtualBrain-Framework Package. This package holds all Data Management, and
-# Web-UI helpful to run brain-simulations. To use it, you also need do download
+# Web-UI helpful to run brain-simulations. To use it, you also need to download
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2023, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -19,12 +19,8 @@
 #
 #
 #   CITATION:
-# When using The Virtual Brain for scientific publications, please cite it as follows:
-#
-#   Paula Sanz Leon, Stuart A. Knock, M. Marmaduke Woodman, Lia Domide,
-#   Jochen Mersmann, Anthony R. McIntosh, Viktor Jirsa (2013)
-#       The Virtual Brain: a simulator of primate brain network dynamics.
-#   Frontiers in Neuroinformatics (7:10. doi: 10.3389/fninf.2013.00010)
+# When using The Virtual Brain for scientific publications, please cite it as explained here:
+# https://www.thevirtualbrain.org/tvb/zwei/neuroscience-publications
 #
 #
 from tvb.core.entities.file.simulator.burst_configuration_h5 import BurstConfigurationH5
@@ -35,12 +31,12 @@ from tvb.datatypes.graph import ConnectivityMeasure, CorrelationCoefficients, Co
 from tvb.datatypes.local_connectivity import LocalConnectivity
 from tvb.datatypes.mode_decompositions import PrincipalComponents, IndependentComponents
 from tvb.datatypes.patterns import StimuliRegion, StimuliSurface, SpatioTemporalPattern
-from tvb.datatypes.projections import ProjectionMatrix, make_proj_matrix
+from tvb.datatypes.projections import ProjectionMatrix, make_proj_matrix, ProjectionsTypeEnum
 from tvb.datatypes.region_mapping import RegionVolumeMapping, RegionMapping
-from tvb.datatypes.sensors import Sensors, make_sensors
+from tvb.datatypes.sensors import Sensors, make_sensors, SensorTypesEnum
 from tvb.datatypes.spectral import CoherenceSpectrum, ComplexCoherenceSpectrum, FourierSpectrum, WaveletCoefficients
 from tvb.datatypes.structural import StructuralMRI
-from tvb.datatypes.surfaces import Surface, make_surface
+from tvb.datatypes.surfaces import Surface, make_surface, SurfaceTypesEnum
 from tvb.datatypes.temporal_correlations import CrossCorrelation
 from tvb.datatypes.time_series import TimeSeries, TimeSeriesRegion, TimeSeriesSurface, TimeSeriesVolume
 from tvb.datatypes.time_series import TimeSeriesEEG, TimeSeriesMEG, TimeSeriesSEEG
@@ -102,17 +98,18 @@ def populate_datatypes_registry():
     REGISTRY.register_datatype(Connectivity, ConnectivityH5, ConnectivityIndex)
     REGISTRY.register_datatype(None, BurstConfigurationH5, BurstConfiguration)
     REGISTRY.register_datatype(LocalConnectivity, LocalConnectivityH5, LocalConnectivityIndex)
-    REGISTRY.register_datatype(ProjectionMatrix, ProjectionMatrixH5, ProjectionMatrixIndex, make_proj_matrix)
+    REGISTRY.register_datatype(ProjectionMatrix, ProjectionMatrixH5, ProjectionMatrixIndex, make_proj_matrix,
+                               ProjectionsTypeEnum)
     REGISTRY.register_datatype(RegionVolumeMapping, RegionVolumeMappingH5, RegionVolumeMappingIndex)
     REGISTRY.register_datatype(RegionMapping, RegionMappingH5, RegionMappingIndex)
-    REGISTRY.register_datatype(Sensors, SensorsH5, SensorsIndex, make_sensors)
+    REGISTRY.register_datatype(Sensors, SensorsH5, SensorsIndex, make_sensors, SensorTypesEnum)
     REGISTRY.register_datatype(SimulationHistory, SimulationHistoryH5, SimulationHistoryIndex)
     REGISTRY.register_datatype(CoherenceSpectrum, CoherenceSpectrumH5, CoherenceSpectrumIndex)
     REGISTRY.register_datatype(ComplexCoherenceSpectrum, ComplexCoherenceSpectrumH5, ComplexCoherenceSpectrumIndex)
     REGISTRY.register_datatype(FourierSpectrum, FourierSpectrumH5, FourierSpectrumIndex)
     REGISTRY.register_datatype(WaveletCoefficients, WaveletCoefficientsH5, WaveletCoefficientsIndex)
     REGISTRY.register_datatype(StructuralMRI, StructuralMRIH5, StructuralMRIIndex)
-    REGISTRY.register_datatype(Surface, SurfaceH5, SurfaceIndex, make_surface)
+    REGISTRY.register_datatype(Surface, SurfaceH5, SurfaceIndex, make_surface, SurfaceTypesEnum)
     REGISTRY.register_datatype(CrossCorrelation, CrossCorrelationH5, CrossCorrelationIndex)
     REGISTRY.register_datatype(TimeSeries, TimeSeriesH5, TimeSeriesIndex)
     REGISTRY.register_datatype(TimeSeriesRegion, TimeSeriesRegionH5, TimeSeriesRegionIndex)
