@@ -2,11 +2,11 @@
 #
 #
 # TheVirtualBrain-Framework Package. This package holds all Data Management, and
-# Web-UI helpful to run brain-simulations. To use it, you also need do download
+# Web-UI helpful to run brain-simulations. To use it, you also need to download
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2023, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -19,12 +19,8 @@
 #
 #
 #   CITATION:
-# When using The Virtual Brain for scientific publications, please cite it as follows:
-#
-#   Paula Sanz Leon, Stuart A. Knock, M. Marmaduke Woodman, Lia Domide,
-#   Jochen Mersmann, Anthony R. McIntosh, Viktor Jirsa (2013)
-#       The Virtual Brain: a simulator of primate brain network dynamics.
-#   Frontiers in Neuroinformatics (7:10. doi: 10.3389/fninf.2013.00010)
+# When using The Virtual Brain for scientific publications, please cite it as explained here:
+# https://www.thevirtualbrain.org/tvb/zwei/neuroscience-publications
 #
 #
 
@@ -37,18 +33,15 @@ Populate Surface fields after 1.3.1, in version 1.4.
 import json
 from sqlalchemy.sql import text
 from tvb.basic.logger.builder import get_logger
-# from tvb.basic.traits.types_basic import MapAsJson
 from tvb.core.entities import model
 from tvb.core.entities.storage import SA_SESSIONMAKER, dao, transactional
-from tvb.core.entities.file.files_helper import FilesHelper
 from tvb.core.utils import parse_json_parameters
 from tvb.datatypes.region_mapping import RegionMapping
-
+from tvb.storage.storage_interface import StorageInterface
 
 LOGGER = get_logger(__name__)
 
 
-
 def update():
     """
     Try to port Projection Matrices and Simulation Configurations from old to new form.
@@ -62,7 +55,6 @@ def update():
     _transfer_projection_matrices()
 
 
-
 @transactional
 def _adapt_epileptor_simulations():
     """
@@ -78,7 +70,7 @@ def _adapt_epileptor_simulations():
     try:
         all_ep_ops = session.query(model.Operation).filter(
             model.Operation.parameters.ilike('%"' + epileptor_old + '"%')).all()
-        files_helper = FilesHelper()
+        storage_interface = StorageInterface()
         all_bursts = dict()
 
         for ep_op in all_ep_ops:
@@ -92,7 +84,7 @@ def _adapt_epileptor_simulations():
                 op_params[param_model] = epileptor_new
                 ep_op.parameters = json.dumps(op_params, cls=MapAsJson.MapAsJsonEncoder)
                 LOGGER.debug("New params:" + ep_op.parameters)
-                files_helper.write_operation_metadata(ep_op)
+                storage_interface.write_operation_metadata(ep_op)
 
                 burst = dao.get_burst_for_operation_id(ep_op.id)
                 if burst is not None:
@@ -134,7 +126,6 @@ def _adapt_simulation_monitor_params():
     try:
         all_eeg_ops = session.query(model.Operation).filter(
             model.Operation.parameters.ilike('%"' + param_eeg_proj_old + '"%')).all()
-        files_helper = FilesHelper()
         all_bursts = dict()
 
         for eeg_op in all_eeg_ops:
