@@ -2,11 +2,11 @@
 #
 #
 # TheVirtualBrain-Framework Package. This package holds all Data Management, and
-# Web-UI helpful to run brain-simulations. To use it, you also need do download
+# Web-UI helpful to run brain-simulations. To use it, you also need to download
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2023, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -19,12 +19,8 @@
 #
 #
 #   CITATION:
-# When using The Virtual Brain for scientific publications, please cite it as follows:
-#
-#   Paula Sanz Leon, Stuart A. Knock, M. Marmaduke Woodman, Lia Domide,
-#   Jochen Mersmann, Anthony R. McIntosh, Viktor Jirsa (2013)
-#       The Virtual Brain: a simulator of primate brain network dynamics.
-#   Frontiers in Neuroinformatics (7:10. doi: 10.3389/fninf.2013.00010)
+# When using The Virtual Brain for scientific publications, please cite it as explained here:
+# https://www.thevirtualbrain.org/tvb/zwei/neuroscience-publications
 #
 #
 
@@ -36,11 +32,12 @@ Upgrade script from H5 version 2 to version 3
 """
 
 import os
+
 from tvb.basic.profile import TvbProfile
-from tvb.core.entities.file.exceptions import FileVersioningException
-from tvb.core.entities.file.hdf5_storage_manager import HDF5StorageManager
 from tvb.core.entities.transient.structure_entities import DataTypeMetaData
 from tvb.core.services.import_service import ImportService
+from tvb.storage.h5.file.exceptions import FileVersioningException
+from tvb.storage.storage_interface import StorageInterface
 
 
 def update_localconnectivity_metadata(folder, file_name):
@@ -70,18 +67,18 @@ def update(input_file, burst_match_dict=None):
                                       "valid file on the disk." % input_file)
 
     folder, file_name = os.path.split(input_file)
-    storage_manager = HDF5StorageManager(folder, file_name)
+    storage_manager = StorageInterface.get_storage_manager(input_file)
 
-    root_metadata = storage_manager.get_metadata()
+    root_metadata = storage_interface.get_metadata(input_file)
     class_name = root_metadata[DataTypeMetaData.KEY_CLASS_NAME]
 
     if class_name == "LocalConnectivity":
         root_metadata[DataTypeMetaData.KEY_MODULE] = "tvb.datatypes.local_connectivity"
-        storage_manager.set_metadata(root_metadata)
+        storage_interface.set_metadata(input_file, root_metadata)
         update_localconnectivity_metadata(folder, file_name)
 
     elif class_name == "RegionMapping":
         root_metadata[DataTypeMetaData.KEY_MODULE] = "tvb.datatypes.region_mapping"
 
     root_metadata[TvbProfile.current.version.DATA_VERSION_ATTRIBUTE] = TvbProfile.current.version.DATA_VERSION
-    storage_manager.set_metadata(root_metadata)
+    storage_interface.set_metadata(input_file, root_metadata)
