@@ -2,11 +2,11 @@
 #
 #
 # TheVirtualBrain-Framework Package. This package holds all Data Management, and
-# Web-UI helpful to run brain-simulations. To use it, you also need do download
+# Web-UI helpful to run brain-simulations. To use it, you also need to download
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2022, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2023, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -18,13 +18,9 @@
 # program.  If not, see <http://www.gnu.org/licenses/>.
 #
 #
-# CITATION:
-# When using The Virtual Brain for scientific publications, please cite it as follows:
-#
-# Paula Sanz Leon, Stuart A. Knock, M. Marmaduke Woodman, Lia Domide,
-#   Jochen Mersmann, Anthony R. McIntosh, Viktor Jirsa (2013)
-#       The Virtual Brain: a simulator of primate brain network dynamics.
-#   Frontiers in Neuroinformatics (7:10. doi: 10.3389/fninf.2013.00010)
+#   CITATION:
+# When using The Virtual Brain for scientific publications, please cite it as explained here:
+# https://www.thevirtualbrain.org/tvb/zwei/neuroscience-publications
 #
 #
 
@@ -59,7 +55,7 @@ from tvb.core.services.import_service import OPERATION_XML, ImportService, Opera
 from tvb.core.utils import date2string, string2date
 from tvb.datatypes.sensors import SensorTypesEnum
 from tvb.storage.h5.file.exceptions import MissingDataSetException, IncompatibleFileManagerException, \
-    FileMigrationException, MissingMatlabOctavePathException
+    FileMigrationException
 from tvb.storage.storage_interface import StorageInterface
 
 LOGGER = get_logger(__name__)
@@ -1279,9 +1275,7 @@ def update(input_file, burst_match_dict):
             algorithm = dao.get_algorithm_by_module(alg_json['module'], alg_json['classname'])
 
             if algorithm is None:
-                raise MissingMatlabOctavePathException(alg_json['classname'] + 'data file could not be migrated.'
-                                                                               ' Please specify a valid path to locally'
-                                                                               ' installed Matlab or Octave!')
+                raise FileMigrationException(alg_json['classname'] + 'data file could not be migrated.')
             operation.algorithm = algorithm
             operation.fk_from_algo = algorithm.id
 
