@@ -2,11 +2,11 @@
 #
 #
 # TheVirtualBrain-Framework Package. This package holds all Data Management, and
-# Web-UI helpful to run brain-simulations. To use it, you also need do download
+# Web-UI helpful to run brain-simulations. To use it, you also need to download
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2022, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2023, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -19,12 +19,8 @@
 #
 #
 #   CITATION:
-# When using The Virtual Brain for scientific publications, please cite it as follows:
-#
-#   Paula Sanz Leon, Stuart A. Knock, M. Marmaduke Woodman, Lia Domide,
-#   Jochen Mersmann, Anthony R. McIntosh, Viktor Jirsa (2013)
-#       The Virtual Brain: a simulator of primate brain network dynamics.
-#   Frontiers in Neuroinformatics (7:10. doi: 10.3389/fninf.2013.00010)
+# When using The Virtual Brain for scientific publications, please cite it as explained here:
+# https://www.thevirtualbrain.org/tvb/zwei/neuroscience-publications
 #
 #
 
@@ -119,7 +115,7 @@ class FilterChain(object):
         new_values.extend(other.values)
         operations = self.operations[:]
         operations.extend(other.operations)
-        return FilterChain(new_display_name, new_fields, new_values, operations, 'and')
+        return FilterChain(new_display_name, new_fields, new_values, operations, self.operator_between_fields)
 
     def __str__(self):
         return self.__class__.__name__ + "(fields=%s, operations=%s, values=%s, operator_between_fields=%s)" % (
@@ -186,8 +182,7 @@ class FilterChain(object):
                            values=filter_dictionary[KEY_VALUES], operations=filter_dictionary[KEY_OPERATIONS],
                            operator_between_fields=filter_dictionary[KEY_OPERATOR])
 
-    def get_python_filter_equivalent(self, datatype_to_check=None, algorithm_to_check=None,
-                                     algocategory_to_check=None, operation_to_check=None):
+    def get_python_filter_equivalent(self, datatype_to_check=None):
         """
         Python evaluate of the filter against a current given DataType
         Check a filter instance next to a given input.
