@@ -2,11 +2,11 @@
 #
 #
 # TheVirtualBrain-Framework Package. This package holds all Data Management, and 
-# Web-UI helpful to run brain-simulations. To use it, you also need do download
+# Web-UI helpful to run brain-simulations. To use it, you also need to download
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2023, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -19,12 +19,8 @@
 #
 #
 #   CITATION:
-# When using The Virtual Brain for scientific publications, please cite it as follows:
-#
-#   Paula Sanz Leon, Stuart A. Knock, M. Marmaduke Woodman, Lia Domide,
-#   Jochen Mersmann, Anthony R. McIntosh, Viktor Jirsa (2013)
-#       The Virtual Brain: a simulator of primate brain network dynamics.
-#   Frontiers in Neuroinformatics (7:10. doi: 10.3389/fninf.2013.00010)
+# When using The Virtual Brain for scientific publications, please cite it as explained here:
+# https://www.thevirtualbrain.org/tvb/zwei/neuroscience-publications
 #
 #
 
@@ -115,7 +111,9 @@ class OperationDAO(RootDAO):
             self.logger.exception(excep)
             return None
 
-    def get_operations(self, status=[STATUS_PENDING, STATUS_STARTED], algorithm_classname="SimulatorAdapter"):
+    def get_operations(self, status=None, algorithm_classname="SimulatorAdapter"):
+        if status is None:
+            status = [STATUS_PENDING, STATUS_STARTED]
         try:
             result = self.session.query(Operation).join(Algorithm) \
                 .filter(Algorithm.classname == algorithm_classname) \
@@ -125,6 +123,21 @@ class OperationDAO(RootDAO):
             self.logger.exception(excep)
             return None
 
+    def get_operations_for_hpc_job(self):
+        status = [STATUS_PENDING, STATUS_STARTED]
+        algorithm_classname = "SimulatorAdapter"
+        queue_full = False
+        try:
+            result = self.session.query(Operation).join(Algorithm) \
+                .filter(Algorithm.classname == algorithm_classname) \
+                .filter(Operation.status.in_(status)) \
+                .filter(Operation.queue_full == queue_full).all()
+            return result
+        except SQLAlchemyError as excep:
+            self.logger.exception(excep)
+            return None
+
+
     def is_upload_operation(self, operation_gid):
         """
         Returns True only if the operation with the given gid is an upload operation.
