@@ -2,11 +2,11 @@
 #
 #
 # TheVirtualBrain-Framework Package. This package holds all Data Management, and
-# Web-UI helpful to run brain-simulations. To use it, you also need do download
+# Web-UI helpful to run brain-simulations. To use it, you also need to download
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2022, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2023, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -19,12 +19,8 @@
 #
 #
 #   CITATION:
-# When using The Virtual Brain for scientific publications, please cite it as follows:
-#
-#   Paula Sanz Leon, Stuart A. Knock, M. Marmaduke Woodman, Lia Domide,
-#   Jochen Mersmann, Anthony R. McIntosh, Viktor Jirsa (2013)
-#       The Virtual Brain: a simulator of primate brain network dynamics.
-#   Frontiers in Neuroinformatics (7:10. doi: 10.3389/fninf.2013.00010)
+# When using The Virtual Brain for scientific publications, please cite it as explained here:
+# https://www.thevirtualbrain.org/tvb/zwei/neuroscience-publications
 #
 #
 
@@ -221,6 +217,15 @@ class StrField(TraitField):
     template = 'form_fields/str_field.html'
 
 
+class UserSessionStrField(TraitField):
+    template = 'form_fields/str_field.html'
+
+    def __init__(self, trait_attribute, name=None, disabled=False, key=None):
+        # type: (Attr, str, bool, str) -> None
+        self.key = key # Key in session
+        super(UserSessionStrField, self).__init__(trait_attribute, name, disabled)
+
+
 class BoolField(TraitField):
     template = 'form_fields/bool_field.html'
 
@@ -295,7 +300,7 @@ class SelectField(TraitField):
             self.template = 'form_fields/select_field.html'
 
     def __init__(self, trait_attribute, name=None, disabled=False, display_none_choice=True,
-                 subform=None, display_subform=True, ui_values=None):
+                 subform=None, display_subform=True, ui_values=None, session_key=None, form_key=None):
         super(SelectField, self).__init__(trait_attribute, name, disabled)
 
         self.choices = list(trait_attribute.choices)
@@ -308,6 +313,8 @@ class SelectField(TraitField):
             self.display_subform = display_subform
         self._prepare_template(self.choices)
         self.ui_values = ui_values
+        self.session_key = session_key
+        self.form_key = form_key
 
     @property
     def value(self):
@@ -343,7 +350,6 @@ class SelectField(TraitField):
         data_as_enum = TVBEnum.string_to_enum(self.choices, self.unvalidated_data)
         if self.unvalidated_data != self.missing_value and data_as_enum is None \
                 and (self.unvalidated_data is not None or self.display_none_choice is False):
-
             raise ValueError("the entered value is not among the choices for this field!")
 
         self.data = data_as_enum
@@ -390,11 +396,13 @@ class DynamicSelectField(TraitField):
                     checked=self.data is None
                 )
 
+        choices = self.choices if self.ui_values is None else self.ui_values
+
         for i, choice in enumerate(self.choices):
             yield Option(
                 id='{}_{}'.format(self.name, i),
                 value=str(choice),
-                label=str(choice).title(),
+                label=str(choices[i]),
                 checked=self.value == choice
             )
 
@@ -404,7 +412,6 @@ class DynamicSelectField(TraitField):
         data_as_object = self.__string_to_object()
         if self.unvalidated_data != self.missing_value and data_as_object is None \
                 and (self.unvalidated_data is not None or self.display_none_choice is False):
-
             raise ValueError("the entered value is not among the choices for this field!")
 
         self.data = data_as_object
@@ -465,6 +472,18 @@ class HiddenField(TraitField):
         self.label = ''
 
 
+class LabelField(TraitField):
+    template = 'form_fields/label_field.html'
+
+    def __init__(self, trait_attribute, label_message=None, name=None):
+        super(LabelField, self).__init__(trait_attribute, name, disabled=True)
+
+        if label_message is None:
+            self.label_message = trait_attribute.label
+        else:
+            self.label_message = label_message
+
+
 class FormField(Field):
     template = 'form_fields/form_field.html'
 
@@ -488,7 +507,8 @@ class Form(object):
     def __init__(self):
         self.errors = []
 
-    def get_subform_key(self):
+    @staticmethod
+    def get_subform_key():
         """
         If the current form can be used as subform, this method should return the proper value.
         """
