@@ -2,11 +2,11 @@
 #
 #
 # TheVirtualBrain-Framework Package. This package holds all Data Management, and
-# Web-UI helpful to run brain-simulations. To use it, you also need do download
+# Web-UI helpful to run brain-simulations. To use it, you also need to download
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2023, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -19,16 +19,11 @@
 #
 #
 #   CITATION:
-# When using The Virtual Brain for scientific publications, please cite it as follows:
-#
-#   Paula Sanz Leon, Stuart A. Knock, M. Marmaduke Woodman, Lia Domide,
-#   Jochen Mersmann, Anthony R. McIntosh, Viktor Jirsa (2013)
-#       The Virtual Brain: a simulator of primate brain network dynamics.
-#   Frontiers in Neuroinformatics (7:10. doi: 10.3389/fninf.2013.00010)
+# When using The Virtual Brain for scientific publications, please cite it as explained here:
+# https://www.thevirtualbrain.org/tvb/zwei/neuroscience-publications
 #
 #
 
-import cgi
 import json
 import os
 import sys
@@ -42,7 +37,7 @@ from tvb.core.entities.model.model_operation import STATUS_STARTED, STATUS_FINIS
 from tvb.core.neocom import h5
 from tvb.core.services.authorization import AuthorizationManager
 from tvb.core.services.backend_clients.hpc_scheduler_client import HPCSchedulerClient
-from tvb.core.services.encryption_handler import EncryptionHandler
+from tvb.storage.storage_interface import StorageInterface
 
 log = get_logger(__name__)
 
@@ -66,15 +61,15 @@ def do_operation_launch(simulator_gid, available_disk_space, is_group_launch, ba
         log.info("Preparing HPC launch for simulation with id={}".format(simulator_gid))
         populate_datatypes_registry()
         log.info("Current TVB profile has HPC run=: {}".format(TvbProfile.current.hpc.IS_HPC_RUN))
-        encyrption_handler = EncryptionHandler(simulator_gid)
-        _request_passfile(simulator_gid, operation_id, base_url, encyrption_handler.get_password_file())
-        encyrption_handler.decrypt_results_to_dir(plain_dir)
+        encryption_handler = StorageInterface.get_encryption_handler(simulator_gid)
+        _request_passfile(simulator_gid, operation_id, base_url, encryption_handler.get_password_file())
+        encryption_handler.decrypt_results_to_dir(plain_dir)
         log.info("Current wdir is: {}".format(plain_dir))
         view_model = h5.load_view_model(simulator_gid, plain_dir)
         adapter_instance = HPCSimulatorAdapter(plain_dir, is_group_launch)
         _update_operation_status(STATUS_STARTED, simulator_gid, operation_id, base_url)
         adapter_instance._prelaunch(None, view_model, available_disk_space)
-        _encrypt_results(adapter_instance, encyrption_handler)
+        _encrypt_results(adapter_instance, encryption_handler)
         _update_operation_status(STATUS_FINISHED, simulator_gid, operation_id, base_url)
 
     except Exception as excep:
