@@ -2,11 +2,11 @@
 #
 #
 # TheVirtualBrain-Framework Package. This package holds all Data Management, and
-# Web-UI helpful to run brain-simulations. To use it, you also need do download
+# Web-UI helpful to run brain-simulations. To use it, you also need to download
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2023, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -19,12 +19,8 @@
 #
 #
 #   CITATION:
-# When using The Virtual Brain for scientific publications, please cite it as follows:
-#
-#   Paula Sanz Leon, Stuart A. Knock, M. Marmaduke Woodman, Lia Domide,
-#   Jochen Mersmann, Anthony R. McIntosh, Viktor Jirsa (2013)
-#       The Virtual Brain: a simulator of primate brain network dynamics.
-#   Frontiers in Neuroinformatics (7:10. doi: 10.3389/fninf.2013.00010)
+# When using The Virtual Brain for scientific publications, please cite it as explained here:
+# https://www.thevirtualbrain.org/tvb/zwei/neuroscience-publications
 #
 #
 
@@ -32,22 +28,23 @@ import json
 import os
 from datetime import datetime
 
-from tvb.adapters.datatypes.db.mapped_value import DatatypeMeasureIndex
-from tvb.adapters.datatypes.db.time_series import TimeSeriesIndex
-from tvb.adapters.datatypes.h5.time_series_h5 import TimeSeriesH5
 from tvb.basic.logger.builder import get_logger
 from tvb.config import MEASURE_METRICS_MODULE, MEASURE_METRICS_CLASS
-from tvb.core.entities.file.files_helper import FilesHelper
 from tvb.core.entities.file.simulator.burst_configuration_h5 import BurstConfigurationH5
 from tvb.core.entities.file.simulator.datatype_measure_h5 import DatatypeMeasureH5
+from tvb.core.entities.file.simulator.view_model import SimulatorAdapterModel
+from tvb.core.entities.generic_attributes import GenericAttributes
 from tvb.core.entities.model.model_burst import BurstConfiguration
 from tvb.core.entities.model.model_datatype import DataTypeGroup
 from tvb.core.entities.model.model_operation import Operation, STATUS_FINISHED, STATUS_PENDING, STATUS_CANCELED
 from tvb.core.entities.model.model_operation import OperationGroup, STATUS_ERROR, STATUS_STARTED, has_finished
 from tvb.core.entities.storage import dao
+from tvb.core.entities.transient.range_parameter import RangeParameter
 from tvb.core.neocom import h5
 from tvb.core.neocom.h5 import DirLoader
+from tvb.core.services.import_service import ImportService
 from tvb.core.utils import format_bytes_human, format_timedelta
+from tvb.storage.storage_interface import StorageInterface
 
 MAX_BURSTS_DISPLAYED = 50
 STATUS_FOR_OPERATION = {
@@ -65,9 +62,9 @@ class BurstService(object):
 
     def __init__(self):
         self.logger = get_logger(self.__class__.__module__)
-        self.file_helper = FilesHelper()
+        self.storage_interface = StorageInterface()
 
-    def mark_burst_finished(self, burst_entity, burst_status=None, error_message=None):
+    def mark_burst_finished(self, burst_entity, burst_status=None, error_message=None, store_h5_file=True):
         """
         Mark Burst status field.
         Also compute 'weight' for current burst: no of operations inside, estimate time on disk...
@@ -96,14 +93,16 @@ class BurstService(object):
             burst_entity.error_message = error_message
             burst_entity.finish_time = datetime.now()
             dao.store_entity(burst_entity)
-            self.update_burst_configuration_h5(burst_entity)
+            if store_h5_file:
+                self.store_burst_configuration(burst_entity)
         except Exception:
             self.logger.exception("Could not correctly update Burst status and meta-data!")
             burst_entity.status = burst_status
             burst_entity.error_message = "Error when updating Burst Status"
             burst_entity.finish_time = datetime.now()
             dao.store_entity(burst_entity)
-            self.update_burst_configuration_h5(burst_entity)
+            if store_h5_file:
+                self.store_burst_configuration(burst_entity)
 
     def persist_operation_state(self, operation, operation_status, message=None):
         """
@@ -114,6 +113,7 @@ class BurstService(object):
         :return: operation instance changed
         """
         operation.mark_complete(operation_status, message)
+        operation.queue_full = False
         operation = dao.store_entity(operation)
         # update burst also
         burst_config = self.get_burst_for_operation_id(operation.id)
@@ -134,7 +134,7 @@ class BurstService(object):
         burst = dao.get_burst_by_id(burst_id)
         burst.name = new_name
         dao.store_entity(burst)
-        self.update_burst_configuration_h5(burst)
+        self.store_burst_configuration(burst)
 
     @staticmethod
     def get_available_bursts(project_id):
@@ -142,8 +142,6 @@ class BurstService(object):
         Return all the burst for the current project.
         """
         bursts = dao.get_bursts_for_project(project_id, page_size=MAX_BURSTS_DISPLAYED) or []
-        # for burst in bursts:
-        #     burst.prepare_after_load()
         return bursts
 
     @staticmethod
@@ -158,12 +156,12 @@ class BurstService(object):
 
     def update_history_status(self, id_list):
         """
-        For each burst_id received in the id_list read new status from DB and return a list [id, new_status] pair.
+        For each burst_id received in the id_list read new status from DB and return a list
+        [id, new_status, is_group, message, running_time] tuple.
         """
         result = []
         for b_id in id_list:
             burst = dao.get_burst_by_id(b_id)
-            # burst.prepare_after_load()
             if burst is not None:
                 if burst.status == burst.BURST_RUNNING:
                     running_time = datetime.now() - burst.start_time
@@ -181,25 +179,25 @@ class BurstService(object):
         return result
 
     @staticmethod
-    def update_simulation_fields(burst_id, op_simulation_id, simulation_gid):
-        burst = dao.get_burst_by_id(burst_id)
+    def update_simulation_fields(burst, op_simulation_id, simulation_gid):
         burst.fk_simulation = op_simulation_id
         burst.simulator_gid = simulation_gid.hex
         burst = dao.store_entity(burst)
         return burst
 
-    def update_burst_configuration_h5(self, burst_configuration):
-        # type: (BurstConfiguration) -> None
-        project = dao.get_project_by_id(burst_configuration.fk_project)
-        storage_path = self.file_helper.get_project_folder(project, str(burst_configuration.fk_simulation))
-        self.store_burst_configuration(burst_configuration, storage_path)
-
-    def load_burst_configuration(self, burst_config_id):
+    @staticmethod
+    def load_burst_configuration(burst_config_id):
         # type: (int) -> BurstConfiguration
         burst_config = dao.get_burst_by_id(burst_config_id)
         return burst_config
 
-    def prepare_burst_for_pse(self, burst_config):
+    @staticmethod
+    def remove_burst_configuration(burst_config_id):
+        # type: (int) -> None
+        dao.remove_entity(BurstConfiguration, burst_config_id)
+
+    @staticmethod
+    def prepare_burst_for_pse(burst_config):
         # type: (BurstConfiguration) -> (BurstConfiguration)
         operation_group = OperationGroup(burst_config.fk_project, ranges=burst_config.ranges)
         operation_group = dao.store_entity(operation_group)
@@ -213,12 +211,15 @@ class BurstService(object):
         burst_config.fk_metric_operation_group = metric_operation_group.id
         return dao.store_entity(burst_config)
 
-    def store_burst_configuration(self, burst_config, storage_path):
-        bc_path = h5.path_for(storage_path, BurstConfigurationH5, burst_config.gid)
+    @staticmethod
+    def store_burst_configuration(burst_config):
+        project = dao.get_project_by_id(burst_config.fk_project)
+        bc_path = h5.path_for(burst_config.fk_simulation, BurstConfigurationH5, burst_config.gid, project.name)
         with BurstConfigurationH5(bc_path) as bc_h5:
             bc_h5.store(burst_config)
 
-    def load_burst_configuration_from_folder(self, simulator_folder, project):
+    @staticmethod
+    def load_burst_configuration_from_folder(simulator_folder, project):
         bc_h5_filename = DirLoader(simulator_folder, None).find_file_for_has_traits_type(BurstConfiguration)
         burst_config = BurstConfiguration(project.id)
         with BurstConfigurationH5(os.path.join(simulator_folder, bc_h5_filename)) as bc_h5:
@@ -226,44 +227,53 @@ class BurstService(object):
         return burst_config
 
     @staticmethod
-    def prepare_name(burst, project_id):
+    def prepare_simulation_name(burst, project_id):
         simulation_number = dao.get_number_of_bursts(project_id) + 1
 
         if burst.name is None:
-            default_simulation_name = 'simulation_' + str(simulation_number)
+            simulation_name = 'simulation_' + str(simulation_number)
         else:
-            default_simulation_name = burst.name
+            simulation_name = burst.name
 
-        return default_simulation_name, simulation_number
+        return simulation_name, simulation_number
 
     def prepare_indexes_for_simulation_results(self, operation, result_filenames, burst):
         indexes = list()
         self.logger.debug("Preparing indexes for simulation results in operation {}...".format(operation.id))
         for filename in result_filenames:
-            index = h5.index_for_h5_file(filename)()
-            h5_class = h5.REGISTRY.get_h5file_for_index(type(index))
+            try:
+                self.logger.debug("Preparing index for filename: {}".format(filename))
+                index = h5.index_for_h5_file(filename)()
+                h5_class = h5.REGISTRY.get_h5file_for_index(type(index))
 
-            with h5_class(filename) as ts_h5:
-                index.fill_from_h5(ts_h5)
-                index.fill_from_generic_attributes(ts_h5.load_generic_attributes())
-                index.gid = ts_h5.gid.load().hex
+                with h5_class(filename) as index_h5:
+                    index.fill_from_h5(index_h5)
+                    index.fill_from_generic_attributes(index_h5.load_generic_attributes())
 
-            index.fk_parent_burst = burst.gid
-            index.fk_from_operation = operation.id
-            if operation.fk_operation_group:
-                datatype_group = dao.get_datatypegroup_by_op_group_id(operation.fk_operation_group)
+                index.fk_parent_burst = burst.gid
+                index.fk_from_operation = operation.id
+                if operation.fk_operation_group:
+                    datatype_group = dao.get_datatypegroup_by_op_group_id(operation.fk_operation_group)
+                    self.logger.debug(
+                        "Found DatatypeGroup with id {} for operation {}".format(datatype_group.id, operation.id))
+                    index.fk_datatype_group = datatype_group.id
+
+                    # Update the operation group name
+                    operation_group = dao.get_operationgroup_by_id(operation.fk_operation_group)
+                    operation_group.fill_operationgroup_name("TimeSeriesRegionIndex")
+                    dao.store_entity(operation_group)
                 self.logger.debug(
-                    "Found DatatypeGroup with id {} for operation {}".format(datatype_group.id, operation.id))
-                index.fk_datatype_group = datatype_group.id
-            self.logger.debug(
-                "Prepared index {} for file {} in operation {}".format(index.summary_info, filename, operation.id))
-            indexes.append(index)
+                    "Prepared index {} for file {} in operation {}".format(index.summary_info, filename, operation.id))
+                indexes.append(index)
+            except Exception as e:
+                self.logger.debug("Skip preparing index {} because there was an error.".format(filename))
+                self.logger.error(e)
         self.logger.debug("Prepared {} indexes for results in operation {}...".format(len(indexes), operation.id))
         return indexes
 
     def prepare_index_for_metric_result(self, operation, result_filename, burst):
         self.logger.debug("Preparing index for metric result in operation {}...".format(operation.id))
-        index = DatatypeMeasureIndex()
+        index = h5.index_for_h5_file(result_filename)()
         with DatatypeMeasureH5(result_filename) as dti_h5:
             index.gid = dti_h5.gid.load().hex
             index.metrics = json.dumps(dti_h5.metrics.load())
@@ -321,5 +331,54 @@ class BurstService(object):
                                      range_values=range_values)
         metric_operation.visible = False
         metric_operation = dao.store_entity(metric_operation)
-        op_dir = FilesHelper().get_project_folder(operation.project, str(metric_operation.id))
+        op_dir = StorageInterface().get_project_folder(operation.project.name, str(metric_operation.id))
         return op_dir, metric_operation
+
+    @staticmethod
+    def get_range_param_by_name(param_name, all_range_parameters):
+        for range_param in all_range_parameters:
+            if param_name == range_param.name:
+                return range_param
+
+        return None
+
+    @staticmethod
+    def handle_range_params_at_loading(burst_config, all_range_parameters):
+        param1, param2 = None, None
+        if burst_config.range1:
+            param1 = RangeParameter.from_json(burst_config.range1)
+            param1.fill_from_default(BurstService.get_range_param_by_name(param1.name, all_range_parameters))
+            if burst_config.range2 is not None:
+                param2 = RangeParameter.from_json(burst_config.range2)
+                param2.fill_from_default(BurstService.get_range_param_by_name(param2.name, all_range_parameters))
+
+        return param1, param2
+
+    def prepare_data_for_burst_copy(self, burst_config_id, burst_name_format, project):
+        burst_config = self.load_burst_configuration(burst_config_id)
+        burst_config_copy = burst_config.clone()
+        count = dao.count_bursts_with_name(burst_config.name, burst_config.fk_project)
+        burst_config_copy.name = burst_name_format.format(burst_config.name, count + 1)
+
+        storage_path = self.storage_interface.get_project_folder(project.name, str(burst_config.fk_simulation))
+        simulator = h5.load_view_model(burst_config.simulator_gid, storage_path)
+        simulator.generic_attributes = GenericAttributes()
+        return simulator, burst_config_copy
+
+    @staticmethod
+    def store_burst(burst_config):
+        return dao.store_entity(burst_config)
+
+    def load_simulation_from_zip(self, zip_file, project):
+        import_service = ImportService()
+        simulator_folder = import_service.import_simulator_configuration_zip(zip_file)
+
+        simulator_h5_filename = DirLoader(simulator_folder, None).find_file_for_has_traits_type(SimulatorAdapterModel)
+        simulator_h5_filepath = os.path.join(simulator_folder, simulator_h5_filename)
+        simulator = h5.load_view_model_from_file(simulator_h5_filepath)
+
+        burst_config = self.load_burst_configuration_from_folder(simulator_folder, project)
+        burst_config_copy = burst_config.clone()
+        simulator.generic_attributes.parent_burst = burst_config_copy.gid
+
+        return simulator, burst_config_copy, simulator_folder
