@@ -2,11 +2,11 @@
 #
 #
 # TheVirtualBrain-Framework Package. This package holds all Data Management, and
-# Web-UI helpful to run brain-simulations. To use it, you also need do download
+# Web-UI helpful to run brain-simulations. To use it, you also need to download
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2023, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -19,12 +19,8 @@
 #
 #
 #   CITATION:
-# When using The Virtual Brain for scientific publications, please cite it as follows:
-#
-#   Paula Sanz Leon, Stuart A. Knock, M. Marmaduke Woodman, Lia Domide,
-#   Jochen Mersmann, Anthony R. McIntosh, Viktor Jirsa (2013)
-#       The Virtual Brain: a simulator of primate brain network dynamics.
-#   Frontiers in Neuroinformatics (7:10. doi: 10.3389/fninf.2013.00010)
+# When using The Virtual Brain for scientific publications, please cite it as explained here:
+# https://www.thevirtualbrain.org/tvb/zwei/neuroscience-publications
 #
 #
 
@@ -39,7 +35,6 @@ Module in charge with Launching an operation (creating the Operation entity as w
 
 import json
 import os
-import shutil
 import sys
 import uuid
 import zipfile
@@ -51,7 +46,6 @@ from tvb.basic.profile import TvbProfile
 from tvb.config import MEASURE_METRICS_MODULE, MEASURE_METRICS_CLASS, MEASURE_METRICS_MODEL_CLASS, ALGORITHMS
 from tvb.core.adapters.abcadapter import ABCAdapter, AdapterLaunchModeEnum
 from tvb.core.adapters.exceptions import LaunchException
-from tvb.core.entities.file.files_helper import FilesHelper
 from tvb.core.entities.generic_attributes import GenericAttributes
 from tvb.core.entities.load import get_class_by_name
 from tvb.core.entities.model.model_burst import PARAM_RANGE_PREFIX, RANGE_PARAMETER_1, RANGE_PARAMETER_2, \
@@ -66,10 +60,13 @@ from tvb.core.services.burst_service import BurstService
 from tvb.core.services.exceptions import OperationException
 from tvb.core.services.project_service import ProjectService
 from tvb.datatypes.time_series import TimeSeries
+from tvb.storage.storage_interface import StorageInterface
 
 RANGE_PARAMETER_1 = RANGE_PARAMETER_1
 RANGE_PARAMETER_2 = RANGE_PARAMETER_2
 
+GROUP_BURST_PENDING = {}
+
 
 class OperationService:
     """
@@ -81,12 +78,21 @@ class OperationService:
 
     def __init__(self):
         self.logger = get_logger(self.__class__.__module__)
-        self.file_helper = FilesHelper()
+        self.storage_interface = StorageInterface()
 
     ##########################################################################################
     ######## Methods related to launching operations start here ##############################
     ##########################################################################################
 
+    def fits_max_operation_size(self, adapter_instance, view_model, project_id, range_length=1):
+        project = dao.get_project_by_id(project_id)
+        if project.max_operation_size is None:
+            return True
+
+        adapter_instance.configure(view_model)
+        adapter_required_memory = adapter_instance.get_required_disk_size(view_model)
+        return adapter_required_memory * range_length < project.max_operation_size
+
     def initiate_operation(self, current_user, project, adapter_instance, visible=True, model_view=None):
         """
         Gets the parameters of the computation from the previous inputs form,
@@ -202,9 +208,9 @@ class OperationService:
 
     @staticmethod
     def store_view_model(operation, project, view_model):
-        storage_path = FilesHelper().get_project_folder(project, str(operation.id))
+        storage_path = StorageInterface().get_project_folder(project.name, str(operation.id))
         h5.store_view_model(view_model, storage_path)
-        view_model_size_on_disk = FilesHelper.compute_recursive_h5_disk_usage(storage_path)
+        view_model_size_on_disk = StorageInterface.compute_recursive_h5_disk_usage(storage_path)
         operation.view_model_disk_size = view_model_size_on_disk
         dao.store_entity(operation)
 
@@ -214,6 +220,7 @@ class OperationService:
         This should be the common point in calling an adapter- method.
         """
         result_msg = ""
+        nr_datatypes = 0
         temp_files = []
         try:
             operation = dao.get_operation_by_id(operation.id)  # Load Lazy fields
@@ -229,7 +236,7 @@ class OperationService:
                 form = form() if isclass(form) else form
                 fields = form.get_upload_field_names()
                 project = dao.get_project_by_id(operation.fk_launched_in)
-                tmp_folder = self.file_helper.get_project_folder(project, self.file_helper.TEMP_FOLDER)
+                tmp_folder = self.storage_interface.get_temp_folder(project.name)
                 for upload_field in fields:
                     if hasattr(view_model, upload_field):
                         file = getattr(view_model, upload_field)
@@ -259,7 +266,7 @@ class OperationService:
             msg = "Could not launch Operation with the given input data!"
             self._handle_exception(excep1, temp_files, msg, operation)
 
-        if operation.fk_operation_group and 'SimulatorAdapter' in operation.algorithm.classname:
+        if operation.fk_operation_group and 'SimulatorAdapter' in operation.algorithm.classname and nr_datatypes == 1:
             next_op = self._prepare_metric_operation(operation)
             self.launch_operation(next_op.id)
         return result_msg
@@ -278,8 +285,11 @@ class OperationService:
     @staticmethod
     def _update_vm_generic_operation_tag(view_model, operation):
         project = dao.get_project_by_id(operation.fk_launched_in)
-        storage_path = FilesHelper().get_project_folder(project, str(operation.id))
-        h5_path = h5.path_for(storage_path, ViewModelH5, view_model.gid, type(view_model).__name__)
+        h5_path = h5.path_for(operation.id, ViewModelH5, view_model.gid, project.name, type(view_model).__name__)
+
+        if not os.path.exists(h5_path):
+            return
+
         with ViewModelH5(h5_path, view_model) as vm_h5:
             vm_h5.operation_tag.store(operation.user_group)
 
@@ -326,7 +336,7 @@ class OperationService:
                     if os.path.exists(pth) and os.path.isfile(pth):
                         os.remove(pth)
                         if len(os.listdir(os.path.dirname(pth))) == 0:
-                            shutil.rmtree(os.path.dirname(pth))
+                            self.storage_interface.remove_folder(os.path.dirname(pth))
                         self.logger.debug("We no longer need file:" + pth + " => deleted")
                     else:
                         self.logger.warning("Trying to remove not existent file:" + pth)
@@ -391,4 +401,5 @@ class OperationService:
                 ProjectService().remove_operation(operation_id)
                 if burst_config is not None:
                     result = dao.remove_entity(BurstConfiguration, burst_config.id) or result
+
         return result
